is_allowed

Function is_allowed 

pub fn is_allowed(name: &str) -> bool
What: Check whether details loading is currently allowed for a package name.

Inputs:

  • name: Package name to test

Output:

  • true when the name is currently allowed; otherwise false (or true if the lock fails).

Details:

  • Fails open when the read lock cannot be acquired to avoid blocking UI interactions.