pub fn is_allowed(name: &str) -> boolExpand description
What: Check whether details loading is currently allowed for a package name.
Inputs:
name: Package name to test
Output:
truewhen the name is currently allowed; otherwisefalse(ortrueif the lock fails).
Details:
- Fails open when the read lock cannot be acquired to avoid blocking UI interactions.