pub fn set_allowed_ring(app: &AppState, radius: usize)Expand description
What: Allow details loading for a “ring” around the current selection.
Inputs:
app: Application state to read the current selection and results fromradius: Number of neighbors above and below to include
Output:
- Updates the internal allowed set to the ring of names around the selection.
Details:
- Includes the selected package itself and symmetrically expands within bounds while respecting the radius.